pytest-selenium
===============

pytest-selenium is a plugin for `pytest <http://pytest.org>`_ that provides
support for running `Selenium <http://seleniumhq.org/>`_ based tests.

.. image:: https://img.shields.io/badge/license-MPL%202.0-blue.svg
   :target: https://github.com/pytest-dev/pytest-selenium/blob/master/LICENSE
   :alt: License
.. image:: https://img.shields.io/pypi/v/pytest-selenium.svg
   :target: https://pypi.python.org/pypi/pytest-selenium/
   :alt: PyPI
.. image:: https://img.shields.io/travis/pytest-dev/pytest-selenium.svg
   :target: https://travis-ci.org/pytest-dev/pytest-selenium/
   :alt: Travis
.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg
   :target: http://pytest-selenium.readthedocs.io/en/latest/
   :alt: Read the Docs
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
.. image:: https://img.shields.io/github/issues-raw/pytest-dev/pytest-selenium.svg
   :target: https://github.com/pytest-dev/pytest-selenium/issues
   :alt: Issues
.. image:: https://img.shields.io/requires/github/pytest-dev/pytest-selenium.svg
   :target: https://requires.io/github/pytest-dev/pytest-selenium/requirements/?branch=master
   :alt: Requirements

Resources
---------

- `Documentation <http://pytest-selenium.readthedocs.io/en/latest/>`_
- `Issue Tracker <http://github.com/pytest-dev/pytest-selenium/issues>`_
- `Code <http://github.com/pytest-dev/pytest-selenium/>`_
